@@ -63,6 +63,15 @@ _current_row_holder: ContextVar[list[sqlalchemy.Row | None] | None] = ContextVar
 
 
 def get_table_key_or_name(table: sqlalchemy.Table | sqlalchemy.Alias) -> str:
+    """
+    Retrieves the key or name of a SQLAlchemy table or alias.
+
+    Args:
+        table (sqlalchemy.Table | sqlalchemy.Alias): The SQLAlchemy table or alias object.
+
+    Returns:
+        str: The key or name of the table/alias.
+    """
     try:
         return table.key  # type: ignore
     except AttributeError:
@@ -71,6 +80,17 @@ def get_table_key_or_name(table: sqlalchemy.Table | sqlalchemy.Alias) -> str:
 
 
 def _extract_unique_lookup_key(obj: Any, unique_fields: Sequence[str]) -> tuple | None:
+    """
+    Extracts a unique lookup key from an object or dictionary based on a sequence of fields.
+
+    Args:
+        obj (Any): The object or dictionary from which to extract the lookup key.
+        unique_fields (Sequence[str]): A sequence of field names that constitute the unique key.
+
+    Returns:
+        tuple | None: A tuple representing the unique lookup key, or None if any unique field
+                      is missing in the object/dictionary.
+    """
     lookup_key = []
     if isinstance(obj, dict):
         for field in unique_fields:
@@ -125,7 +145,6 @@ class BaseQuerySet(
         defer_fields: Sequence[str] | None = None,
         defer: Iterable[str] = _empty_set,
         embed_parent: tuple[str, str | str] | None = None,
-        embed_parent_filters: tuple[str, str] | None = None,
         using_schema: str | None | Any = Undefined,
         table: sqlalchemy.Table | None = None,
         exclude_secrets: bool = False,
@@ -153,8 +172,14 @@ class BaseQuerySet(
             )
             offset = limit_offset
         self._offset = offset
-
-        self._select_related = set(select_related)
+        # Have the user passed select related values copied
+        select_related = set(select_related)
+        # Have the **real** path values
+        self._select_related: set[str] = set()
+        # computed only, replacable. Have the **real** path values
+        self._select_related_weak: set[str] = set()
+        if select_related:
+            self._update_select_related(select_related)
         self._prefetch_related = list(prefetch_related)
         self._batch_size = batch_size
         self._order_by: tuple[str, ...] = tuple(order_by)
@@ -181,7 +206,9 @@ class BaseQuerySet(
             defer = defer_fields
         self._defer = set(defer)
         self.embed_parent = embed_parent
-        self.embed_parent_filters = embed_parent_filters
+        # private attribute which manipulates the prefix of filters, order_by, select_related
+        # set by relations
+        self.embed_parent_filters: tuple[str, str | str] | None = None
         self.using_schema = using_schema
         self._extra_select = list(extra_select) if extra_select is not None else []
         self._reference_select = (
@@ -215,7 +242,6 @@ class BaseQuerySet(
             self.model_class,
             database=getattr(self, "_database", None),
             filter_clauses=self.filter_clauses,
-            select_related=self._select_related,
             prefetch_related=self._prefetch_related,
             limit=self.limit_count,
             offset=self._offset,
@@ -226,7 +252,6 @@ class BaseQuerySet(
             only=self._only,
             defer=self._defer,
             embed_parent=self.embed_parent,
-            embed_parent_filters=self.embed_parent_filters,
             using_schema=self.using_schema,
             table=getattr(self, "_table", None),
             exclude_secrets=self._exclude_secrets,
@@ -234,16 +259,32 @@ class BaseQuerySet(
             extra_select=self._extra_select,
         )
         queryset.or_clauses.extend(self.or_clauses)
+        queryset.embed_parent_filters = self.embed_parent_filters
+        # copy but don't trigger update select related
+        queryset._select_related.update(self._select_related)
+        queryset._select_related_weak.update(self._select_related_weak)
         queryset._cached_select_related_expression = self._cached_select_related_expression
         return cast("QuerySet", queryset)
 
     @cached_property
     def _has_dynamic_clauses(self) -> bool:
+        """
+        Indicates if the queryset has any dynamic (callable) filter or OR clauses.
+        """
         return any(callable(clause) for clause in chain(self.filter_clauses, self.or_clauses))
 
     def _clear_cache(
         self, *, keep_result_cache: bool = False, keep_cached_selected: bool = False
     ) -> None:
+        """
+        Clears the internal cache of the queryset.
+
+        Args:
+            keep_result_cache (bool): If True, the result cache (for fetched models) is preserved.
+                                      Defaults to False.
+            keep_cached_selected (bool): If True, the cached select expression and tables are preserved.
+                                         Defaults to False.
+        """
         if not keep_result_cache:
             self._cache.clear()
         if not keep_cached_selected:
@@ -256,20 +297,27 @@ class BaseQuerySet(
         # fetch all is in cache
         self._cache_fetch_all: bool = False
 
-    def _build_order_by_expression(self, order_by: Any, expression: Any) -> Any:
-        """Builds the order by expression"""
-        expression = expression.order_by(*(self._prepare_order_by(entry) for entry in order_by))
-        return expression
-
-    def _build_group_by_expression(self, group_by: Any, expression: Any) -> Any:
-        """Builds the group by expression"""
-        expression = expression.group_by(*(self._prepare_order_by(entry) for entry in group_by))
-        return expression
+    def _build_order_by_iterable(
+        self, order_by: Iterable[str], tables_and_models: tables_and_models_type
+    ) -> Iterable:
+        """Builds the iterator for a order by like expression."""
+        return (self._prepare_order_by(entry, tables_and_models) for entry in order_by)
 
     async def build_where_clause(
         self, _: Any = None, tables_and_models: tables_and_models_type | None = None
     ) -> Any:
-        """Build a where clause from the filters which can be passed in a where function."""
+        """
+        Builds a SQLAlchemy WHERE clause from the queryset's filter and OR clauses.
+
+        Args:
+            _ (Any): Ignored. Used for compatibility with `clauses_mod.parse_clause_arg` signature.
+            tables_and_models (tables_and_models_type | None): A dictionary mapping table aliases to
+                                                               (table, model) tuples. If None, it's
+                                                               built internally. Defaults to None.
+
+        Returns:
+            Any: The combined SQLAlchemy WHERE clause.
+        """
         joins: Any | None = None
         if tables_and_models is None:
             joins, tables_and_models = self._build_tables_join_from_relationship()
@@ -311,11 +359,21 @@ class BaseQuerySet(
             )
         )
 
-    def _build_select_distinct(self, distinct_on: Sequence[str] | None, expression: Any) -> Any:
+    def _build_select_distinct(
+        self,
+        distinct_on: Sequence[str] | None,
+        expression: Any,
+        tables_and_models: tables_and_models_type,
+    ) -> Any:
         """Filters selects only specific fields. Leave empty to use simple distinct"""
         # using with columns is not supported by all databases
         if distinct_on:
-            return expression.distinct(*map(self._prepare_fields_for_distinct, distinct_on))
+            return expression.distinct(
+                *(
+                    self._prepare_distinct(distinct_el, tables_and_models)
+                    for distinct_el in distinct_on
+                )
+            )
         else:
             return expression.distinct()
 
@@ -328,6 +386,20 @@ class BaseQuerySet(
         transitions: dict[tuple[str, str, str], tuple[Any, tuple[str, str, str] | None, str]],
         tables_and_models: dict[str, tuple[sqlalchemy.Table, type[BaseModelType]]],
     ) -> Any:
+        """
+        Recursively builds SQLAlchemy join clauses based on a transition map.
+
+        Args:
+            join_clause (Any): The current join clause to which new joins are added.
+            current_transition (tuple[str, str, str]): The key for the current transition.
+            transitions (dict[tuple[str, str, str], tuple[Any, tuple[str, str, str] | None, str]]):
+                A dictionary mapping transition keys to (join_condition, parent_transition_key, table_alias) tuples.
+            tables_and_models (dict[str, tuple[sqlalchemy.Table, type[BaseModelType]]]):
+                A dictionary mapping table aliases to (table, model) tuples.
+
+        Returns:
+            Any: The updated join clause.
+        """
         if current_transition not in transitions:
             return join_clause
         transition_value = transitions.pop(current_transition)
@@ -351,10 +423,20 @@ class BaseQuerySet(
         self,
     ) -> tuple[Any, tables_and_models_type]:
         """
-        Builds the tables relationships and joins.
-        When a table contains more than one foreign key pointing to the same
-        destination table, a lookup for the related field is made to understand
-        from which foreign key the table is looked up from.
+        Builds the table relationships and joins for `select_related` operations.
+
+        This method constructs a graph of table joins based on the `_select_related` paths.
+        It handles many-to-many relationships and aliasing of tables to ensure uniqueness.
+        The result is cached for performance.
+
+        Returns:
+            tuple[Any, tables_and_models_type]: A tuple containing:
+                - The SQLAlchemy join expression.
+                - A dictionary mapping table aliases (prefixes) to (table, model) tuples.
+
+        Raises:
+            QuerySetError: If a selected field does not exist or is not a RelationshipField,
+                           or if a selected model is on another database.
         """
 
         # How does this work?
@@ -377,7 +459,7 @@ class BaseQuerySet(
             ] = {}
 
             # Select related
-            for select_path in self._select_related:
+            for select_path in self._select_related.union(self._select_related_weak):
                 # For m2m relationships
                 model_class = self.model_class
                 former_table = maintable
@@ -501,6 +583,18 @@ class BaseQuerySet(
         reverse: bool,
         former_table: Any,
     ) -> Any:
+        """
+        Generates SQLAlchemy WHERE clauses for joining tables based on a foreign key relationship.
+
+        Args:
+            foreign_key (BaseForeignKey): The foreign key field defining the relationship.
+            table (Any): The SQLAlchemy table for the related model.
+            reverse (bool): True if the relationship is being traversed in reverse (from related to source model).
+            former_table (Any): The SQLAlchemy table for the source model.
+
+        Yields:
+            Any: SQLAlchemy binary expressions for the join condition.
+        """
         column_names = foreign_key.get_column_names(foreign_key.name)
         assert column_names, f"foreign key without column names detected: {foreign_key.name}"
         for col in column_names:
@@ -513,6 +607,12 @@ class BaseQuerySet(
                 )
 
     def _validate_only_and_defer(self) -> None:
+        """
+        Validates that .only() and .defer() are not used simultaneously.
+
+        Raises:
+            QuerySetError: If both .only() and .defer() are applied to the queryset.
+        """
         if self._only and self._defer:
             raise QuerySetError("You cannot use .only() and .defer() at the same time.")
 
@@ -520,7 +620,19 @@ class BaseQuerySet(
         self,
     ) -> tuple[Any, tables_and_models_type]:
         """
-        Builds the query select based on the given parameters and filters.
+        Builds the SQLAlchemy SELECT expression along with the mapping of tables and models,
+        based on the queryset's parameters and filters.
+
+        This method handles `only`, `defer`, `exclude_secrets`, `extra_select`, and
+        `reference_select` clauses, and incorporates `select_related` joins.
+
+        Returns:
+            tuple[Any, tables_and_models_type]: A tuple containing:
+                - The constructed SQLAlchemy SELECT expression.
+                - A dictionary mapping table aliases to (table, model) tuples.
+
+        Raises:
+            AssertionError: If no columns or extra_select elements are specified for the query.
         """
         self._validate_only_and_defer()
         joins, tables_and_models = self._build_tables_join_from_relationship()
@@ -574,7 +686,14 @@ class BaseQuerySet(
         expression = expression.where(await self.build_where_clause(self, tables_and_models))
 
         if self._order_by:
-            expression = self._build_order_by_expression(self._order_by, expression=expression)
+            expression = expression.order_by(
+                *self._build_order_by_iterable(self._order_by, tables_and_models)
+            )
+
+        if self._group_by:
+            expression = expression.group_by(
+                *self._build_order_by_iterable(self._group_by, tables_and_models)
+            )
 
         if self.limit_count:
             expression = expression.limit(self.limit_count)
@@ -582,18 +701,22 @@ class BaseQuerySet(
         if self._offset:
             expression = expression.offset(self._offset)
 
-        if self._group_by:
-            expression = self._build_group_by_expression(self._group_by, expression=expression)
-
         if self.distinct_on is not None:
-            expression = self._build_select_distinct(self.distinct_on, expression=expression)
+            expression = self._build_select_distinct(
+                self.distinct_on, expression=expression, tables_and_models=tables_and_models
+            )
         return expression, tables_and_models
 
     async def as_select_with_tables(
         self,
     ) -> tuple[Any, tables_and_models_type]:
         """
-        Builds the query select based on the given parameters and filters.
+        Builds the query select based on the given parameters and filters, including
+        the mapping of tables and models involved in the query. The result is cached.
+
+        Returns:
+            tuple[Any, tables_and_models_type]: A tuple containing the SQLAlchemy select
+                                                 expression and the tables and models dictionary.
         """
         if self._cached_select_with_tables is None:
             self._cached_select_with_tables = await self._as_select_with_tables()
@@ -602,12 +725,33 @@ class BaseQuerySet(
     async def as_select(
         self,
     ) -> Any:
+        """
+        Builds and returns only the SQLAlchemy select expression for the current queryset.
+
+        Returns:
+            Any: The SQLAlchemy select expression.
+        """
         return (await self.as_select_with_tables())[0]
 
     def _kwargs_to_clauses(
         self,
         kwargs: Any,
     ) -> tuple[list[Any], set[str]]:
+        """
+        Converts keyword arguments into a list of callable filter clauses and a set of
+        `select_related` paths.
+
+        This function handles relationship traversal and cross-database foreign keys,
+        generating appropriate SQLAlchemy expressions or wrapped async functions.
+
+        Args:
+            kwargs (Any): The keyword arguments representing the filter conditions.
+
+        Returns:
+            tuple[list[Any], set[str]]: A tuple containing:
+                - A list of SQLAlchemy binary expressions or async callable wrappers.
+                - A set of relationship paths for `select_related`.
+        """
         clauses = []
         select_related: set[str] = set()
         cleaned_kwargs = clauses_mod.clean_query_kwargs(
@@ -673,18 +817,131 @@ class BaseQuerySet(
 
         return clauses, select_related
 
-    def _prepare_order_by(self, order_by: str) -> Any:
+    def _prepare_order_by(self, order_by: str, tables_and_models: tables_and_models_type) -> Any:
+        """
+        Prepares an order_by or group_by clause from a string.
+
+        Args:
+            order_by (str): The field name for ordering, optionally prefixed with '-' for descending.
+
+        Returns:
+            Any: The SQLAlchemy column expression for ordering and the select_path.
+        """
         reverse = order_by.startswith("-")
         order_by = order_by.lstrip("-")
-        order_col = self.table.columns[order_by]
+        crawl_result = clauses_mod.clean_path_to_crawl_result(
+            self.model_class,
+            path=order_by,
+            embed_parent=self.embed_parent_filters,
+            model_database=self.database,
+        )
+        order_col = tables_and_models[crawl_result.forward_path][0].columns[
+            crawl_result.field_name
+        ]
         return order_col.desc() if reverse else order_col
 
-    def _prepare_fields_for_distinct(self, distinct_on: str) -> sqlalchemy.Column:
-        return self.table.columns[distinct_on]
+    def _update_select_related_weak(self, fields: Iterable[str], *, clear: bool) -> bool:
+        """
+        Update _select_related_weak
+
+        Args:
+            fields (Iterable[str]): The field names of order_by, group_by, ...
+
+        """
+        related: set[str] = set()
+        for field_name in fields:
+            # handle order by values by stripping -
+            field_name = field_name.lstrip("-")
+            related_element = clauses_mod.clean_path_to_crawl_result(
+                self.model_class,
+                path=field_name,
+                embed_parent=self.embed_parent_filters,
+                model_database=self.database,
+            ).forward_path
+            if related_element:
+                related.add(related_element)
+        if related and not self._select_related.union(self._select_related_weak).issuperset(
+            related
+        ):
+            self._cached_select_related_expression = None
+            if clear:
+                self._select_related_weak.clear()
+            self._select_related_weak.update(related)
+            return True
+        return False
+
+    def _update_select_related(self, pathes: Iterable[str]) -> None:
+        """
+        Update _select_related
+
+        Args:
+            pathes (Iterable[str]): The related pathes.
+
+        """
+        related: set[str] = set()
+        for path in pathes:
+            # handle order by values by stripping -
+            path = path.lstrip("-")
+            crawl_result = clauses_mod.clean_path_to_crawl_result(
+                self.model_class,
+                # actually not a field_path
+                path=path,
+                embed_parent=self.embed_parent_filters,
+                model_database=self.database,
+            )
+            # actually not a field name
+            related_element = (
+                crawl_result.field_name
+                if not crawl_result.forward_path
+                else f"{crawl_result.forward_path}__{crawl_result.field_name}"
+            )
+            if crawl_result.cross_db_remainder:
+                raise QuerySetError(
+                    detail=f'Selected path "{related_element}" is on another database.'
+                )
+            if related_element:
+                related.add(related_element)
+        if related and not self._select_related.issuperset(related):
+            self._cached_select_related_expression = None
+            self._select_related.update(related)
+
+    def _prepare_distinct(
+        self, distinct_on: str, tables_and_models: tables_and_models_type
+    ) -> sqlalchemy.Column:
+        """
+        Prepares a field for use in a distinct-on clause.
+
+        Args:
+            distinct_on (str): The field name for distinctness.
+
+        Returns:
+            sqlalchemy.Column: The SQLAlchemy column object.
+        """
+        crawl_result = clauses_mod.clean_path_to_crawl_result(
+            self.model_class,
+            path=distinct_on,
+            embed_parent=self.embed_parent_filters,
+            model_database=self.database,
+        )
+        return tables_and_models[crawl_result.forward_path][0].columns[crawl_result.field_name]
 
     async def _embed_parent_in_result(
         self, result: EdgyModel | Awaitable[EdgyModel]
     ) -> tuple[EdgyModel, Any]:
+        """
+        Embeds a parent model into the result if `embed_parent` is configured.
+
+        This allows accessing related models directly from the main model instance
+        as defined by the `embed_parent` setting.
+
+        Args:
+            result (EdgyModel | Awaitable[EdgyModel]): The model instance or an awaitable
+                                                        that resolves to a model instance.
+
+        Returns:
+            tuple[EdgyModel, Any]: A tuple where the first element is the original result
+                                   and the second is the potentially embedded result.
+        """
         if isawaitable(result):
             result = await result
         if not self.embed_parent:
@@ -709,6 +966,26 @@ class BaseQuerySet(
         extra_attr: str = "",
         raw: bool = False,
     ) -> tuple[EdgyModel, EdgyEmbedTarget]:
+        """
+        Retrieves or caches a single model instance from a SQLAlchemy row.
+
+        This method converts a SQLAlchemy row into a model instance, handles
+        `only_fields`, `defer_fields`, `prefetch_related`, and `embed_parent` configurations,
+        and optionally sets extra attributes on the queryset for caching.
+
+        Args:
+            row (Any): The SQLAlchemy row object.
+            tables_and_models (dict[str, tuple[sqlalchemy.Table, type[BaseModelType]]]):
+                A dictionary mapping table aliases to (table, model) tuples.
+            extra_attr (str): Comma-separated string of attributes to set on the queryset with the result.
+                              Defaults to "".
+            raw (bool): If True, returns the raw model instance without `embed_parent` transformation.
+                        Defaults to False.
+
+        Returns:
+            tuple[EdgyModel, EdgyEmbedTarget]: A tuple containing the raw model instance
+                                               and the potentially embedded target instance.
+        """
         is_defer_fields = bool(self._defer)
         result_tuple: tuple[EdgyModel, EdgyEmbedTarget] = (
             await self._cache.aget_or_cache_many(
@@ -735,6 +1012,15 @@ class BaseQuerySet(
         return result_tuple
 
     def get_schema(self) -> str | None:
+        """
+        Retrieves the active database schema for the queryset.
+
+        The schema can be explicitly set via `using_schema`, obtained from the
+        current context variable, or derived from the model's metadata.
+
+        Returns:
+            str | None: The active schema name, or None if not applicable.
+        """
         # Differs from get_schema global
         schema = self.using_schema
         if schema is Undefined:
@@ -750,6 +1036,25 @@ class BaseQuerySet(
         queryset: BaseQuerySet,
         new_cache: QueryModelResultCache,
     ) -> Sequence[tuple[BaseModelType, BaseModelType]]:
+        """
+        Handles a batch of SQLAlchemy rows, converting them to model instances and
+        performing prefetching operations.
+
+        Args:
+            batch (Sequence[sqlalchemy.Row]): A sequence of SQLAlchemy row objects.
+            tables_and_models (dict[str, tuple[sqlalchemy.Table, type[BaseModelType]]]):
+                A dictionary mapping table aliases to (table, model) tuples.
+            queryset (BaseQuerySet): The current queryset (used for its configuration).
+            new_cache (QueryModelResultCache): The cache to store the new batch results.
+
+        Returns:
+            Sequence[tuple[BaseModelType, BaseModelType]]: A sequence of tuples, each containing
+                                                            the raw model instance and the embedded target.
+
+        Raises:
+            NotImplementedError: If prefetching from another database is attempted.
+            QuerySetError: If creating a reverse path for prefetching is not possible.
+        """
         is_defer_fields = bool(queryset._defer)
         del queryset
         _prefetch_related: list[Prefetch] = []
@@ -835,7 +1140,21 @@ class BaseQuerySet(
         self, fetch_all_at_once: bool = False
     ) -> AsyncIterator[BaseModelType]:
         """
-        Executes the query, iterate.
+        Executes the query and yields model instances during iteration.
+
+        This method supports fetching all results at once or in batches, and handles
+        prefetching and embedding parent models. It also includes warnings for
+        `force_rollback` usage with iterations due to potential deadlocks.
+
+        Args:
+            fetch_all_at_once (bool): If True, all results are fetched before yielding.
+                                      Defaults to False.
+
+        Yields:
+            BaseModelType: A model instance for each row.
+
+        Warns:
+            UserWarning: If using queryset iterations with `Database`-level `force_rollback` enabled.
         """
         if self._cache_fetch_all:
             for result in cast(
@@ -921,6 +1240,9 @@ class BaseQuerySet(
         self._cache_last = last_element
 
     async def _execute_all(self) -> list[EdgyModel]:
+        """
+        Executes the query and returns all results as a list of model instances.
+        """
         return [result async for result in self._execute_iterate(fetch_all_at_once=True)]
 
     def _filter_or_exclude(
@@ -942,6 +1264,25 @@ class BaseQuerySet(
     ) -> QuerySet:
         """
         Filters or excludes a given clause for a specific QuerySet.
+
+        This is an internal method used by `filter`, `exclude`, `or_`, and `and_` to
+        construct the query's WHERE clauses. It handles various clause types including
+        dictionaries (kwargs), callable filters, and other QuerySet objects.
+
+        Args:
+            kwargs (Any): Additional keyword arguments to filter by.
+            clauses (Sequence[...]): A sequence of filter clauses.
+            exclude (bool): If True, the clauses are inverted for exclusion. Defaults to False.
+            or_ (bool): If True, the clauses are combined with OR. Defaults to False.
+            allow_global_or (bool): If True, and only one OR clause is provided, it can be
+                                    added to the queryset's global OR clauses. Defaults to True.
+
+        Returns:
+            QuerySet: A new QuerySet with the applied filters/exclusions.
+
+        Raises:
+            AssertionError: If `exclude` is True and `or_` is also True when adding to global OR.
+            AssertionError: If a `QuerySet` object is used as a clause with a different model class.
         """
         queryset: QuerySet = self._clone()
         if kwargs:
@@ -1006,6 +1347,18 @@ class BaseQuerySet(
         return queryset
 
     async def _model_based_delete(self, remove_referenced_call: str | bool) -> int:
+        """
+        Performs a model-based deletion, iterating through models and calling their `raw_delete` method.
+
+        This method is used when `__require_model_based_deletion__` or `post_delete_fields` are set
+        on the model, ensuring hooks and related object handling are executed.
+
+        Args:
+            remove_referenced_call (str | bool): Specifies how to handle referenced objects during deletion.
+
+        Returns:
+            int: The total number of records deleted.
+        """
         queryset = self.limit(self._batch_size) if not self._cache_fetch_all else self
         # we set embed_parent on the copy to None to get raw instances
         # embed_parent_filters is not affected
@@ -1029,6 +1382,21 @@ class BaseQuerySet(
     async def raw_delete(
         self, use_models: bool = False, remove_referenced_call: str | bool = False
     ) -> int:
+        """
+        Executes a raw delete operation on the database.
+
+        This method can either perform a direct SQL DELETE statement or iterate
+        through models and call their individual `raw_delete` methods based on
+        `use_models` and model configurations.
+
+        Args:
+            use_models (bool): If True, deletion is performed by iterating and
+                               deleting individual model instances. Defaults to False.
+            remove_referenced_call (str | bool): Specifies how to handle referenced objects during deletion.
+
+        Returns:
+            int: The number of rows deleted.
+        """
         if (
             self.model_class.__require_model_based_deletion__
             or self.model_class.meta.post_delete_fields
@@ -1054,6 +1422,20 @@ class BaseQuerySet(
     async def _get_raw(self, **kwargs: Any) -> tuple[BaseModelType, Any]:
         """
         Returns a single record based on the given kwargs.
+
+        This is an internal method that fetches a single row from the database,
+        handling caching and raising exceptions for no results or multiple results.
+
+        Args:
+            **kwargs (Any): Keyword arguments to filter the query.
+
+        Returns:
+            tuple[BaseModelType, Any]: A tuple containing the raw model instance and
+                                       the potentially embedded target instance.
+
+        Raises:
+            ObjectNotFound: If no object matches the given criteria.
+            MultipleObjectsReturned: If more than one object matches the criteria.
         """
 
         if kwargs:
@@ -1097,6 +1479,9 @@ class QuerySet(BaseQuerySet):
     """
 
     async def _sql_helper(self) -> Any:
+        """
+        Helper method to compile the SQL query into a string.
+        """
         async with self.database:
             return (await self.as_select()).compile(
                 self.database.engine, compile_kwargs={"literal_binds": True}
@@ -1234,11 +1619,29 @@ class QuerySet(BaseQuerySet):
         self,
         *extra: sqlalchemy.ColumnClause,
     ) -> QuerySetType:
+        """
+        Adds extra columns or expressions to the SELECT statement.
+
+        Args:
+            *extra (sqlalchemy.ColumnClause): Additional SQLAlchemy column clauses or expressions.
+
+        Returns:
+            QuerySetType: A new QuerySet with the extra select clauses.
+        """
         queryset = self._clone()
         queryset._extra_select.extend(extra)
         return queryset
 
     def reference_select(self, references: reference_select_type) -> QuerySetType:
+        """
+        Adds references to the SELECT statement, used for specific model field handling.
+
+        Args:
+            references (reference_select_type): A dictionary defining reference selections.
+
+        Returns:
+            QuerySetType: A new QuerySet with the added reference selections.
+        """
         queryset = self._clone()
         queryset._reference_select.update(references)
         return queryset
@@ -1256,7 +1659,7 @@ class QuerySet(BaseQuerySet):
 
     def lookup(self, term: Any) -> QuerySet:
         """
-        Broader way of searching for a given term
+        Broader way of searching for a given term on CharField and TextField instances.
         """
         queryset: QuerySet = self._clone()
         if not term:
@@ -1285,9 +1688,17 @@ class QuerySet(BaseQuerySet):
         """
         queryset: QuerySet = self._clone()
         queryset._order_by = order_by
+        if queryset._update_select_related_weak(order_by, clear=True):
+            queryset._update_select_related_weak(queryset._group_by, clear=False)
         return queryset
 
     def reverse(self) -> QuerySet:
+        """
+        Reverses the order of the QuerySet.
+
+        If no `order_by` is set, it defaults to ordering by primary key columns.
+        It also attempts to reverse the cached results for immediate consistency.
+        """
         if not self._order_by:
             queryset = self.order_by(*self.model_class.pkcolumns)
         else:
@@ -1331,11 +1742,21 @@ class QuerySet(BaseQuerySet):
         """
         queryset: QuerySet = self._clone()
         queryset._group_by = group_by
+        if queryset._update_select_related_weak(group_by, clear=True):
+            queryset._update_select_related_weak(queryset._order_by, clear=False)
         return queryset
 
     def distinct(self, first: bool | str = True, *distinct_on: str) -> QuerySet:
         """
         Returns a queryset with distinct results.
+
+        Args:
+            first (bool | str): If True, applies `DISTINCT`. If False, removes any distinct clause.
+                                If a string, applies `DISTINCT ON` to that field.
+            *distinct_on (str): Additional fields for `DISTINCT ON`.
+
+        Returns:
+            QuerySet: A new QuerySet with the distinct clause applied.
         """
         queryset: QuerySet = self._clone()
         if first is False:
@@ -1391,9 +1812,7 @@ class QuerySet(BaseQuerySet):
                 stacklevel=2,
             )
             related = cast(tuple[str, ...], related[0])
-        if not self._select_related.issuperset(related):
-            queryset._cached_select_related_expression = None
-            queryset._select_related.update(related)
+        queryset._update_select_related(related)
         return queryset
 
     async def values(
@@ -1401,7 +1820,7 @@ class QuerySet(BaseQuerySet):
         fields: Sequence[str] | str | None = None,
         exclude: Sequence[str] | set[str] = None,
         exclude_none: bool = False,
-    ) -> list[Any]:
+    ) -> list[dict]:
         """
         Returns the results in a python dictionary format.
         """
@@ -1409,19 +1828,17 @@ class QuerySet(BaseQuerySet):
         if isinstance(fields, str):
             fields = [fields]
 
-        rows: list[BaseModelType] = await self
-
         if fields is not None and not isinstance(fields, Iterable):
             raise QuerySetError(detail="Fields must be a suitable sequence of strings or unset.")
 
-        if not fields:
-            rows = [row.model_dump(exclude=exclude, exclude_none=exclude_none) for row in rows]
-        else:
-            rows = [
+        rows: list[BaseModelType] = await self
+        if fields:
+            return [
                 row.model_dump(exclude=exclude, exclude_none=exclude_none, include=fields)
                 for row in rows
             ]
-        return rows
+        else:
+            return [row.model_dump(exclude=exclude, exclude_none=exclude_none) for row in rows]
 
     async def values_list(
         self,
@@ -1433,6 +1850,8 @@ class QuerySet(BaseQuerySet):
         """
         Returns the results in a python dictionary format.
         """
+        if isinstance(fields, str):
+            fields = [fields]
         rows = await self.values(
             fields=fields,
             exclude=exclude,
@@ -1549,6 +1968,7 @@ class QuerySet(BaseQuerySet):
         token = CHECK_DB_CONNECTION_SILENCED.set(True)
         try:
             instance = queryset.model_class(*args, **kwargs)
+            # apply_instance_extras filters out table Alias
             apply_instance_extras(
                 instance,
                 self.model_class,
@@ -1777,6 +2197,20 @@ class QuerySet(BaseQuerySet):
         return retrieved_objs
 
     async def delete(self, use_models: bool = False) -> int:
+        """
+        Deletes records from the database.
+
+        This method triggers `pre_delete` and `post_delete` signals.
+        If `use_models` is True or the model has specific deletion requirements,
+        it performs a model-based deletion.
+
+        Args:
+            use_models (bool): If True, deletion is performed by iterating and
+                               deleting individual model instances. Defaults to False.
+
+        Returns:
+            int: The number of rows deleted.
+        """
         await self.model_class.meta.signals.pre_delete.send_async(
             self.model_class, instance=self, model_instance=None
         )
